# Generated by Django 4.2.20 on 2025-06-13 14:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('unicom', '0006_channel_created_at_channel_created_by_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='message',
            name='imap_uid',
            field=models.BigIntegerField(blank=True, db_index=True, help_text='IMAP UID for marking as seen', null=True),
        ),
    ]
