# Generated by Django 4.2.20 on 2025-06-10 05:11

from django.db import migrations, models
import unicom.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('unicom', '0004_messagetemplateinlineimage'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailinlineimage',
            name='hash',
            field=models.CharField(blank=True, db_index=True, help_text='SHA256 hash of file for deduplication', max_length=64, null=True),
        ),
        migrations.AddField(
            model_name='messagetemplateinlineimage',
            name='hash',
            field=models.CharField(blank=True, db_index=True, help_text='SHA256 hash of file for deduplication', max_length=64, null=True),
        ),
        migrations.AlterField(
            model_name='emailinlineimage',
            name='file',
            field=unicom.models.fields.DedupFileField(upload_to='email_inline_images/'),
        ),
        migrations.AlterField(
            model_name='messagetemplateinlineimage',
            name='file',
            field=unicom.models.fields.DedupFileField(upload_to='message_template_inline_images/'),
        ),
    ]
